/**
 * Copyright 2018 The original authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.dekorate.examples.component;

import java.net.URL;
import java.util.Optional;
import org.junit.jupiter.api.Test;

import io.dekorate.deps.kubernetes.api.model.*;
import io.dekorate.deps.kubernetes.api.model.apps.*;
import io.dekorate.utils.Serialization;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertEquals;

public class Feat279Test {

  @Test
  public void shouldContainComponent() {
    KubernetesList list = Serialization.unmarshal(Feat279Test.class.getClassLoader().getResourceAsStream("META-INF/dekorate/kubernetes.yml"));
    assertNotNull(list);
    Deployment deployment = findFirst(list, Deployment.class).orElseThrow(IllegalStateException::new);
    assertNotNull(deployment.getSpec().getTemplate().getSpec().getImagePullSecrets());
    assertEquals("my-secret", deployment.getSpec().getTemplate().getSpec().getImagePullSecrets().get(0).getName());
  }

  <T extends HasMetadata> Optional<T> findFirst(KubernetesList list, Class<T> t) {
    return (Optional<T>) list.getItems().stream()
      .filter(i -> t.isInstance(i))
      .findFirst();
  }
}
